/*
 * crash-manager
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __DEF_CONFIG_H_
#define __DEF_CONFIG_H_

#include <stdbool.h>

/* Configuration default values */
/* note: 0 means unlimited */
#define SYSTEM_MAX_USE       0
#define SYSTEM_KEEP_FREE     0
#define MAX_RETENTION_SEC    0
#define MAX_CRASH_DUMP       0
#define DUMP_CORE            1
#define ALLOW_ZIP            1
#define LEGACY_NOTIFICATION  0

#define CRASH_SECTION        "CrashManager"

enum ReportType {
	REP_TYPE_INVALID = -1,
	REP_TYPE_INFO = 0,
	REP_TYPE_FULL,
	REP_TYPE_DEFAULT = REP_TYPE_FULL,
};

typedef struct config {
	bool allow_zip;
	bool dump_core;
	bool legacy_notification;
	int system_max_use;
	int system_keep_free;
	int max_retention_sec;
	int max_crash_dump;
	enum ReportType report_type;
	char *crash_root_path;
	char *extra_script;
} config_t;


#ifdef __cplusplus
extern "C" {
#endif

bool config_init(config_t *c, const char *const path);
void config_free(config_t *c);

#ifdef __cplusplus
}
#endif

/**
 * @}
 */
#endif
